@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.34 2006/11/13 16:49:16 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.38 2019/09/29 10:37:49 werner Exp $
  *
  * Diverse Hilfsfunktionen
  *
@@ -350,11 +350,11 @@ void Print(WINDOW *win, int y, int x, char *str, int color)
    
 #ifdef COLOR_SUPPORT
     wattrset( win, COLOR_PAIR(color) | A_BOLD);
-#else
-    wattrset( win, color);
-#endif
+#endif /* COLOR_SUPPORT */
     waddch(win, ch );
+#ifdef COLOR_SUPPORT
     wattrset( win, 0);
+#endif /* COLOR_SUPPORT */
   }
 }
 
@@ -882,7 +882,12 @@ char *GetExtension(char *filename)
 
   cptr = strrchr(filename, '.');
 
-  return( (cptr) ? cptr + 1 : "" );
+  if(cptr == NULL) return "";
+
+  if(cptr == filename) return "";
+  // filenames beginning with a dot are not an extension
+
+  return(cptr + 1);
 }
 
 
@@ -967,7 +972,7 @@ int BuildUserFileEntry(FileEntry *fe_ptr,
       } else if(!strncmp(sptr, ATTRIBUTE_VIEWNAME, 3)) {
         n = sprintf(dptr, "%10s", attributes);
       } else if(!strncmp(sptr, LINKCOUNT_VIEWNAME, 3)) {
-        n = sprintf(dptr, "%3d", fe_ptr->stat_struct.st_nlink);
+        n = sprintf(dptr, "%3d", (int)fe_ptr->stat_struct.st_nlink);
       } else if(!strncmp(sptr, FILESIZE_VIEWNAME, 3)) {
 #ifdef HAS_LONGLONG
         n = sprintf(dptr, "%7lld", (LONGLONG) fe_ptr->stat_struct.st_size);
@@ -1138,4 +1143,24 @@ static char *GNU_getcwd()
     }
 }
 
+/*****************************************************************************
+ *                              CutName                                      *
+ *****************************************************************************/
+
+char *CutName(char *dest, char *src, unsigned int max_len)
+{
+  unsigned int l;
+
+  l = strlen(src);
+
+  if( l <= max_len )
+    return( strcpy( dest, src ) );
+  else
+  {
+    (void) strncpy( dest, src, max_len - 3 );
+    return strcpy( &dest[max_len - 3], "..." );
+  }
+}
+
+
 
